from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String, Directory

Fasta2Shrep_Gspan_Pl_V0_1_0 = CommandToolBuilder(tool="fasta2shrep_gspan.pl", base_command=["fasta2shrep_gspan.pl"], inputs=[ToolInput(tag="in_man", input_type=Boolean(optional=True), prefix="-man", doc=InputDocumentation(doc="full documentation")), ToolInput(tag="in_shift", input_type=Boolean(optional=True), prefix="-shift", doc=InputDocumentation(doc="<INTEGER> e.g. 20\nThe shift of the window, relative to the window size given in\npercent. So you give which percent of the window size shall be\nused for the shift. Of course the shift is rounded down to the\nnearest whole number.\nExample 20 % of a window 150 would result in a step size of 30 nt.\nIt is a relative parameter, as you can give different window sizes.\nIf you do not give this parameter there is a default shift of 1 nt.")), ToolInput(tag="in_cue", input_type=Boolean(optional=True), prefix="-cue", doc=InputDocumentation(doc="Crop unpaired ends.\nIf you give this flag, then the unpaired ends of each\nsingle structure are ignored. E.g. the structure\n...(((...))).. becomes just (((...)))")), ToolInput(tag="in_stack", input_type=Boolean(optional=True), prefix="-stack", doc=InputDocumentation(doc="Adds stacking information to graphs. This adds an additional\nvertex (type P) for each pair of stacked base-pairs and four edges\n(type p) from each of the involved bases to the new vertex.")), ToolInput(tag="in_float_eg_energy", input_type=Boolean(optional=True), prefix="-e", doc=InputDocumentation(doc="<FLOAT> e.g. 5.0\nEnergy range in kcal/mol (RNAshapes)\nUse only one of -e and -c!")), ToolInput(tag="in_integer_eg_relative", input_type=Boolean(optional=True), prefix="-c", doc=InputDocumentation(doc="<INTEGER> e.g. 10\nRelative energy range, i.e. percentage (%) of MFE energy (RNAshapes)\nUse only one of -e and -c!")), ToolInput(tag="in_integer_shape_type", input_type=Boolean(optional=True), prefix="-t", doc=InputDocumentation(doc="<INTEGER> [1-5] e.g. 3 OR '3=0,4=100,5=200'\nThe shape type (RNAshapes). Default is 3.\nWith the list format, the shape level can be changed for different window length\n'4=100' means that shape level 4 is used from length 100nt (window length)\nThe first given length has to be 0! Not continuous given levels are allowed!")), ToolInput(tag="in_integer_eg_number", input_type=Boolean(optional=True), prefix="-M", doc=InputDocumentation(doc="<INTEGER> e.g. 10\nMax number of shreps that should be taken per window.")), ToolInput(tag="in_ignore_unstable_structures", input_type=Boolean(optional=True), prefix="-u", doc=InputDocumentation(doc="Ignore unstable structures (RNAshapes).\nThis option filters out closed structures with positive free energy.")), ToolInput(tag="in_calculate_structure_probabilities", input_type=Boolean(optional=True), prefix="-r", doc=InputDocumentation(doc="Calculate structure probabilities for shreps (RNAshapes)")), ToolInput(tag="in_int_eg_turn", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="<INT> e.g. 10\nTurn on structure sampling and gives number of sampling iterations.\nDefault no sampling (i=0)")), ToolInput(tag="in_sample_len", input_type=Boolean(optional=True), prefix="-sample-len", doc=InputDocumentation(doc="<INT> e.g. 100\nOnly in sampling mode: Sampling is only used for seqs/windows >= given length,\nDefault: sample all lengths (0), if -i > 0")), ToolInput(tag="in_turn_shape_probabilities", input_type=Boolean(optional=True), prefix="-q", doc=InputDocumentation(doc="Turn on shape probabilities for RNAshapes, no sampling mode allowed")), ToolInput(tag="in_tp", input_type=Boolean(optional=True), prefix="-Tp", doc=InputDocumentation(doc="<FLOAT> e.g 0.001\nFilter cutoff for shape probabilities, applied before -M filter!")), ToolInput(tag="in_seq_graph_win", input_type=Boolean(optional=True), prefix="-seq-graph-win", doc=InputDocumentation(doc="add for each window a graph which contains no structure")), ToolInput(tag="in_seq_graph_t", input_type=Boolean(optional=True), prefix="-seq-graph-t", doc=InputDocumentation(doc="add for each 't #' a graph which contains no structure")), ToolInput(tag="in_seq_graph_alph", input_type=String(optional=True), prefix="-seq-graph-alph", doc=InputDocumentation(doc="the alphabet of unstructured graphs")), ToolInput(tag="in_annotate", input_type=Boolean(optional=True), prefix="-annotate", doc=InputDocumentation(doc="<STRING> annotation.tab\nA file with annotations to be added as abstract graphs\non the sequence leven (if given) and on the structure\n(SHREP) level. The format is has the following TAB-delimited\ncolumns: SEQID, START, END, NAMESPACE#LABEL.\nLabels with the same name-space and SEQID form connected\ncomponents, which is a sequence of label vertices ordered\nby the START position in the sequence.")), ToolInput(tag="in_abstr", input_type=Boolean(optional=True), prefix="-abstr", doc=InputDocumentation(doc="Add abstract structure graphs to the single shrep graph")), ToolInput(tag="in_match_shape", input_type=Boolean(optional=True), prefix="-match-shape", doc=InputDocumentation(doc="<SHAPE>\nall seqs/windows will be constraint folded into that shape via\nRNAshapes (if structure is given in another way this struct will be kept),\nif this shape is not possible within given energy range, produce a\nspecific t graph with only one vertex 'X'. By this the instance\nbecomes very unsimilar to all other graphs (for knn)")), ToolInput(tag="in_vp", input_type=Boolean(optional=True), prefix="-vp", doc=InputDocumentation(doc="enable graph computation with viewpoints:\nsvmsgdnspdk will center on those nucleotides that are given\nvia capital letters and ignore those given as lowercase letters")), ToolInput(tag="in_tmp", input_type=Boolean(optional=True), prefix="-tmp", doc=InputDocumentation(doc="<STRING> e.g. '/scratch/1/sita/tmp'\nA directory for writing temporary files")), ToolInput(tag="in_string_eg_output_directory", input_type=Directory(optional=True), prefix="-o", doc=InputDocumentation(doc="<STRING> e.g. 'ProjectX/MySequences/GSPAN/'\nOutput directory for gspan files containing graphs.")), ToolInput(tag="in_group", input_type=Boolean(optional=True), prefix="-group", doc=InputDocumentation(doc="<INTEGER> e.g. 5\nCombine/group that number of input seqs into 1 gspan file\noutput name is then '<INT>.group.gspan.bz2'")), ToolInput(tag="in_stdout", input_type=Boolean(optional=True), prefix="-stdout", doc=InputDocumentation(doc="send graphs to stdout instead of writing to files")), ToolInput(tag="in_ignore_header", input_type=Boolean(optional=True), prefix="-ignore-header", doc=InputDocumentation(doc="don't write fasta id part after first space to gspan")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="-debug", doc=InputDocumentation(doc="additional debug output")), ToolInput(tag="in_help", input_type=String(), position=0, doc=InputDocumentation(doc="-help   brief help message")), ToolInput(tag="in_compulsory", input_type=String(), position=1, doc=InputDocumentation(doc="-fasta  <STRING> e.g. 'sequence.fasta'\nAll sequences in fasta format.")), ToolInput(tag="in_options", input_type=String(), position=2, doc=InputDocumentation(doc="-wins           [INTEGER] e.g. '50,100,200'\nA list of window sizes to use.\nIf none are given (empty string ''), then the entire sequence is\ntaken with no windows. Each window > 1 required!")), ToolInput(tag="in_instances_dot", input_type=String(), position=3, doc=InputDocumentation(doc="-nostr                  Calculate no structures, only add sequence information,"))], outputs=[ToolOutput(tag="out_string_eg_output_directory", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_string_eg_output_directory", type_hint=File()), doc=OutputDocumentation(doc="<STRING> e.g. 'ProjectX/MySequences/GSPAN/'\nOutput directory for gspan files containing graphs."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Fasta2Shrep_Gspan_Pl_V0_1_0().translate("wdl", allow_empty_container=True)

